@@ -73,7 +73,7 @@ class Project:
                 dict_elements['reportSuites'].append(panel['reportSuite']['id'])
             elif "rsid" in panel.keys():
                 dict_elements['reportSuites'].append(panel['rsid'])
-            filters: list = panel['segmentGroups']
+            filters: list = panel.get('segmentGroups',[])
             if len(filters) > 0:
                 for element in filters:
                     typeElement = element['componentOptions'][0]['component']['type']
@@ -97,7 +97,7 @@ class Project:
                             componentType: str = row['component']['type']
                             if componentType == "DimensionItem":
                                 temp_list_dim.append(row['component']['id'])
-                            elif componentType == "Segments":
+                            elif componentType == "Segments" or componentType == "Segment":
                                 dict_elements['segments'].append(row['component']['id'])
                             elif componentType == "Metric":
                                 dict_elements['metrics'].append(row['component']['id'])
